@@ -289,8 +289,6 @@ sub twigMzxml_addMSMSSpectrum{
     $spmsms->set('fragPD', $pd_mzintcharge);
     $spmsms->setSampleInfo('spectrumType', 'msms');
     $spmsms->setSampleInfo('sampleNumber', $is++);
-    $spmsms->setSampleInfo('instrument', 'n/a');
-    $spmsms->setSampleInfo('instrumentID', 'n/a');
 
     $this->addSpectra($spmsms);
   }
@@ -434,8 +432,6 @@ sub twigMzdata_addMSMSSpectrum{
     $spmsms->set('fragPD', $pd_mzintcharge);
     $spmsms->setSampleInfo('spectrumType', 'msms');
     $spmsms->setSampleInfo('sampleNumber', $is++);
-    $spmsms->setSampleInfo('instrument', 'n/a');
-    $spmsms->setSampleInfo('instrumentID', 'n/a');
 
     $this->addSpectra($spmsms);
   }
